@@ -37,19 +37,27 @@ except ImportError:
 MAX_CONFIG_SEARCH_DEPTH = 25 # The number of parent directories frosted will look for a config file within
 
 # Note that none of these lists must be complete as they are simply fallbacks for when included auto-detection fails.
-default = {'skip': ['__init__.py', ],
-           'ignore_frosted_errors': [],
+default = {'skip': [],
+           'ignore_frosted_errors': ['W201'],
+           'ignore_frosted_errors_for__init__.py': ['E101', 'E103'],
            'verbose': False}
 
 
 @lru_cache()
 def from_path(path):
     computed_settings = default.copy()
-    editor_config_file = os.path.expanduser('~/.editorconfig')
+    _update_settings_with_config(path, '.editorconfig', '~/.editorconfig', ('*', '*.py', '**.py'), computed_settings)
+    _update_settings_with_config(path, 'setup.cfg', None, ('frosted', ), computed_settings)
+    _update_settings_with_config(path, '.frosted.cfg', '~/.frosted.cfg', ('settings', ), computed_settings)
+    return computed_settings
+
+
+def _update_settings_with_config(path, name, default, sections, computed_settings):
+    editor_config_file = default
     tries = 0
-    current_directory = path
+    current_directory = path and os.path.expanduser(path)
     while current_directory and tries < MAX_CONFIG_SEARCH_DEPTH:
-        potential_path = os.path.join(current_directory, native_str(".editorconfig"))
+        potential_path = os.path.join(current_directory, native_str(name))
         if os.path.exists(potential_path):
             editor_config_file = potential_path
             break
@@ -57,8 +65,15 @@ def from_path(path):
         current_directory = os.path.split(current_directory)[0]
         tries += 1
 
-    if os.path.exists(editor_config_file):
-        with open(editor_config_file) as config_file:
+    if editor_config_file and os.path.exists(editor_config_file):
+        computed_settings.update(_read_config_file(editor_config_file, sections).copy())
+
+
+@lru_cache()
+def _read_config_file(file_path, sections):
+    computed_settings = {}
+    with open(file_path) as config_file:
+        if file_path.endswith(".editorconfig"):
             line = "\n"
             last_position = config_file.tell()
             while line:
@@ -68,45 +83,20 @@ def from_path(path):
                     break
                 last_position = config_file.tell()
 
-            config = configparser.SafeConfigParser()
-            config.readfp(config_file)
-            settings = {}
-            if config.has_section('*'):
-                settings.update(dict(config.items('*')))
-            if config.has_section('*.py'):
-                settings.update(dict(config.items('*.py')))
-            if config.has_section('**.py'):
-                settings.update(dict(config.items('**.py')))
-
-            for key, value in settings.items():
-                existing_value_type = type(computed_settings.get(key, ''))
-                if existing_value_type in (list, tuple):
-                    computed_settings[key.lower()] = value.split(",")
-                else:
-                    computed_settings[key.lower()] = existing_value_type(value)
-
-    frosted_config_file = os.path.expanduser('~/.frosted.cfg')
-    tries = 0
-    current_directory = path
-    while current_directory and tries < MAX_CONFIG_SEARCH_DEPTH:
-        potential_path = os.path.join(current_directory, native_str(".frosted.cfg"))
-        if os.path.exists(potential_path):
-            frosted_config_file = potential_path
-            break
-
-        current_directory = os.path.split(current_directory)[0]
-        tries += 1
-
-    if os.path.exists(frosted_config_file):
-        with open(frosted_config_file) as config_file:
-            config = configparser.SafeConfigParser()
-            config.readfp(config_file)
-            settings = dict(config.items('settings'))
-            for key, value in settings.items():
-                existing_value_type = type(computed_settings.get(key, ''))
-                if existing_value_type in (list, tuple):
-                    computed_settings[key.lower()] = value.split(",")
-                else:
-                    computed_settings[key.lower()] = existing_value_type(value)
-
+        config = configparser.SafeConfigParser()
+        config.readfp(config_file)
+        settings = dict()
+        for section in sections:
+            if config.has_section(section):
+                settings.update(dict(config.items(section)))
+        for key, value in settings.items():
+            if key.startswith('ignore_frosted_errors_for'):
+                existing_value_type = list
+            else:
+                existing_value_type = type(default.get(key, ''))
+            if existing_value_type in (list, tuple):
+                computed_settings[key.lower()] = value.split(",")
+            else:
+                computed_settings[key.lower()] = existing_value_type(value)
     return computed_settings
+
